Documentation
¶
Index ¶
- func Input(thread *starlark.Thread, fn *starlark.Builtin, args starlark.Tuple, ...) (starlark.Value, error)
- func InputInt(thread *starlark.Thread, fn *starlark.Builtin, args starlark.Tuple, ...) (starlark.Value, error)
- func InputIntRange(thread *starlark.Thread, fn *starlark.Builtin, args starlark.Tuple, ...) (starlark.Value, error)
- func InputMasked(thread *starlark.Thread, fn *starlark.Builtin, args starlark.Tuple, ...) (starlark.Value, error)
- func LoadModule() starlark.StringDict
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Input ¶
func Input(thread *starlark.Thread, fn *starlark.Builtin, args starlark.Tuple, kwargs []starlark.Tuple) (starlark.Value, error)
Input reads a string from standard input.
Arguments:
prompt: Optional prompt to display.
Returns: string
func InputInt ¶
func InputInt(thread *starlark.Thread, fn *starlark.Builtin, args starlark.Tuple, kwargs []starlark.Tuple) (starlark.Value, error)
InputInt prompts for an integer until a valid one is entered.
Arguments:
prompt: Prompt to display.
Returns: int
func InputIntRange ¶
func InputIntRange(thread *starlark.Thread, fn *starlark.Builtin, args starlark.Tuple, kwargs []starlark.Tuple) (starlark.Value, error)
InputIntRange prompts for an integer that must be within the provided allowed_values.
Arguments:
prompt: Prompt to display. allowed_values: A list of allowed integers.
Returns: int
func InputMasked ¶
func InputMasked(thread *starlark.Thread, fn *starlark.Builtin, args starlark.Tuple, kwargs []starlark.Tuple) (starlark.Value, error)
InputMasked reads a string from standard input with masking.
Arguments:
prompt: Prompt to display.
Returns: string
func LoadModule ¶
func LoadModule() starlark.StringDict
LoadModule returns the dictionary of built-in functions for this module.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.